



import 'dart:developer';
import 'dart:io';

import 'package:finotescore/src/activity_trail.dart';
import 'package:finotescore/src/crash_detector.dart';
import 'package:finotescore/src/platform_interface.dart';
import 'package:finotescore/src/thread_block_detector.dart';
import 'package:flutter/material.dart';

class Fn {

  static void init(){
    if (Platform.isAndroid) {
      FlutterError.onError = Fn.reportFatalError;
      PlatformInterface.init();
      ThreadBlockDetector();
    }else{
      log("Platform not yet supported");
    }
  }

  static void logMe(){
    if (Platform.isAndroid) {
      PlatformInterface.logMe();
    }else{
      log("Platform not yet supported");
    }
  }

  static Future<void> reportFatalError(FlutterErrorDetails flutterErrorDetails) async {
    if (Platform.isAndroid) {
      CrashDetector().processAndReport(flutterErrorDetails.exception.toString(), flutterErrorDetails.stack, 
                  context: flutterErrorDetails.context.toString(), information: flutterErrorDetails.informationCollector!(), fatal: true);
    }else{
      log("Platform not yet supported");
    }
  }

  static void reportError(Object error, StackTrace stackTrace) {
    if (Platform.isAndroid) {
      CrashDetector().processAndReport(error.toString(), stackTrace, fatal: false);
    }else{
      log("Platform not yet supported");
    }
  }


  static void reportIssue(String where, String description, String detailedDescription) {
    if (Platform.isAndroid) {
      PlatformInterface.customIssue(where, description, detailedDescription);
    }else{
      log("Platform not yet supported");
    }
  }


  static void setActivityMarker(String where, String marker) {
    if (Platform.isAndroid) {
      ActivityTrail().addMarker(where, marker);
    }else{
      log("Platform not yet supported");
    }
  }

  static void test() {
    Fn.reportIssue("Fn", "Test Issue Raised", "This issue is raised for test purposes");
  }

}
